# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import datetime
import parler.models


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='News',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('newsbox_creation_date', models.DateTimeField(auto_now_add=True, verbose_name='creation date')),
                ('newsbox_changed_date', models.DateTimeField(auto_now=True, verbose_name='last update date')),
                ('newsbox_date', models.DateTimeField(default=None, help_text='Date of the event related to this news', null=True, verbose_name='date', blank=True)),
                ('newsbox_publication_start_date', models.DateTimeField(default=datetime.datetime.now, help_text='When the news should go live. Status must be "Published" for news to go live.', verbose_name='publication start date', db_index=True)),
                ('newsbox_status', models.CharField(default='draft', help_text='Use "Draft" to prepare your content before publishing and "Archived" to unpublish content without deleting it', max_length=10, verbose_name='status', choices=[('draft', 'draft'), ('published', 'published'), ('archived', 'archived')])),
            ],
            options={
                'ordering': ('-newsbox_publication_start_date',),
                'verbose_name': 'news - I18N',
                'verbose_name_plural': 'news - I18N',
            },
            bases=(parler.models.TranslatableModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='NewsComplete',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('newsbox_creation_date', models.DateTimeField(auto_now_add=True, verbose_name='creation date')),
                ('newsbox_changed_date', models.DateTimeField(auto_now=True, verbose_name='last update date')),
                ('newsbox_date', models.DateTimeField(default=None, help_text='Date of the event related to this news', null=True, verbose_name='date', blank=True)),
                ('newsbox_publication_start_date', models.DateTimeField(default=datetime.datetime.now, help_text='When the news should go live. Status must be "Published" for news to go live.', verbose_name='publication start date', db_index=True)),
                ('newsbox_status', models.CharField(default='draft', help_text='Use "Draft" to prepare your content before publishing and "Archived" to unpublish content without deleting it', max_length=10, verbose_name='status', choices=[('draft', 'draft'), ('published', 'published'), ('archived', 'archived')])),
                ('newsbox_publication_end_date', models.DateTimeField(help_text='When to expire the news.Leave empty to never expire.', null=True, verbose_name='publication end date', db_index=True, blank=True)),
                ('newsbox_indexed', models.PositiveSmallIntegerField(default=1, help_text='An unindexed news will not be indexed by search engines.', verbose_name='indexed', choices=[(0, 'Not indexed on search engines'), (1, 'Indexed on search engines')])),
            ],
            options={
                'ordering': ('-newsbox_publication_start_date',),
                'verbose_name': 'news - CompleteI18N',
                'verbose_name_plural': 'news - CompleteI18N',
            },
            bases=(parler.models.TranslatableModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='NewsCompleteTranslation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('language_code', models.CharField(max_length=15, verbose_name='Language', db_index=True)),
                ('newsbox_title', models.CharField(max_length=255, verbose_name='title')),
                ('newsbox_slug', models.SlugField(help_text='The part of the title that is used in the URL', verbose_name='slug')),
                ('newsbox_summary', models.TextField(verbose_name='summary')),
                ('newsbox_body', models.TextField(verbose_name='body', blank=True)),
                ('newsbox_meta_description', models.TextField(max_length=255, null=True, verbose_name='meta description', blank=True)),
                ('newsbox_meta_keywords', models.CharField(max_length=255, null=True, verbose_name='meta keywords', blank=True)),
                ('newsbox_canonical_url', models.URLField(help_text='Ce champ vous permet d\'indiquer aux moteurs de recherche l\'URL "officielle" d\'un contenu dupliqu\xe9. Si votre contenu provient d\'une autre page (de votre site ou non), alors vous devriez indiquer l\'URL de ce contenu "source" afin d\'\xe9viter que les moteurs de recherches ne vous p\xe9nalisent pour du "contenu dupliqu\xe9". Vous pouvez consultez <a target="_blank" href="http://www.webrankinfo.com/dossiers/techniques/url-canonique">le dossier de webrankinfo</a> \xe0 ce sujet ou <a target="_blank" href="https://support.google.com/webmasters/answer/139066?hl=fr#2">l\'aide google</a>.', null=True, verbose_name='canonical URL', blank=True)),
                ('master', models.ForeignKey(on_delete=models.CASCADE, related_name='translations', editable=False, to='myapp_i18n.NewsComplete', null=True)),
            ],
            options={
                'managed': True,
                'verbose_name_plural': 'News translations',
                'db_table': 'myapp_i18n_newscomplete_translation',
                'db_tablespace': '',
                'default_permissions': (),
                'verbose_name': 'News translation',
            },
        ),
        migrations.CreateModel(
            name='NewsExtended',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('newsbox_creation_date', models.DateTimeField(auto_now_add=True, verbose_name='creation date')),
                ('newsbox_changed_date', models.DateTimeField(auto_now=True, verbose_name='last update date')),
                ('newsbox_date', models.DateTimeField(default=None, help_text='Date of the event related to this news', null=True, verbose_name='date', blank=True)),
                ('newsbox_publication_start_date', models.DateTimeField(default=datetime.datetime.now, help_text='When the news should go live. Status must be "Published" for news to go live.', verbose_name='publication start date', db_index=True)),
                ('newsbox_status', models.CharField(default='draft', help_text='Use "Draft" to prepare your content before publishing and "Archived" to unpublish content without deleting it', max_length=10, verbose_name='status', choices=[('draft', 'draft'), ('published', 'published'), ('archived', 'archived')])),
                ('newsbox_publication_end_date', models.DateTimeField(help_text='When to expire the news.Leave empty to never expire.', null=True, verbose_name='publication end date', db_index=True, blank=True)),
                ('newsbox_indexed', models.PositiveSmallIntegerField(default=1, help_text='An unindexed news will not be indexed by search engines.', verbose_name='indexed', choices=[(0, 'Not indexed on search engines'), (1, 'Indexed on search engines')])),
                ('general_field', models.CharField(max_length=50)),
            ],
            options={
                'ordering': ('-newsbox_publication_start_date',),
                'verbose_name': 'news - ExtendedI18N',
                'verbose_name_plural': 'news - ExtendedI18N',
            },
            bases=(parler.models.TranslatableModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='NewsExtendedTranslation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('language_code', models.CharField(max_length=15, verbose_name='Language', db_index=True)),
                ('content_field', models.CharField(max_length=50)),
                ('seo_field', models.CharField(max_length=50)),
                ('newsbox_title', models.CharField(max_length=255, verbose_name='title')),
                ('newsbox_slug', models.SlugField(help_text='The part of the title that is used in the URL', verbose_name='slug')),
                ('newsbox_summary', models.TextField(verbose_name='summary')),
                ('newsbox_body', models.TextField(verbose_name='body', blank=True)),
                ('newsbox_meta_description', models.TextField(max_length=255, null=True, verbose_name='meta description', blank=True)),
                ('newsbox_meta_keywords', models.CharField(max_length=255, null=True, verbose_name='meta keywords', blank=True)),
                ('newsbox_canonical_url', models.URLField(help_text='Ce champ vous permet d\'indiquer aux moteurs de recherche l\'URL "officielle" d\'un contenu dupliqu\xe9. Si votre contenu provient d\'une autre page (de votre site ou non), alors vous devriez indiquer l\'URL de ce contenu "source" afin d\'\xe9viter que les moteurs de recherches ne vous p\xe9nalisent pour du "contenu dupliqu\xe9". Vous pouvez consultez <a target="_blank" href="http://www.webrankinfo.com/dossiers/techniques/url-canonique">le dossier de webrankinfo</a> \xe0 ce sujet ou <a target="_blank" href="https://support.google.com/webmasters/answer/139066?hl=fr#2">l\'aide google</a>.', null=True, verbose_name='canonical URL', blank=True)),
                ('master', models.ForeignKey(on_delete=models.CASCADE, related_name='translations', editable=False, to='myapp_i18n.NewsExtended', null=True)),
            ],
            options={
                'managed': True,
                'verbose_name_plural': 'News translations',
                'db_table': 'myapp_i18n_newsextended_translation',
                'db_tablespace': '',
                'default_permissions': (),
                'verbose_name': 'News translation',
            },
        ),
        migrations.CreateModel(
            name='NewsTranslation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('language_code', models.CharField(max_length=15, verbose_name='Language', db_index=True)),
                ('newsbox_title', models.CharField(max_length=255, verbose_name='title')),
                ('newsbox_slug', models.SlugField(help_text='The part of the title that is used in the URL', verbose_name='slug')),
                ('newsbox_summary', models.TextField(verbose_name='summary')),
                ('newsbox_body', models.TextField(verbose_name='body', blank=True)),
                ('master', models.ForeignKey(on_delete=models.CASCADE, related_name='translations', editable=False, to='myapp_i18n.News', null=True)),
            ],
            options={
                'managed': True,
                'verbose_name_plural': 'News translations',
                'db_table': 'myapp_i18n_news_translation',
                'db_tablespace': '',
                'default_permissions': (),
                'verbose_name': 'News translation',
            },
        ),
        migrations.AlterUniqueTogether(
            name='newstranslation',
            unique_together=set([('language_code', 'master'), ('newsbox_slug', 'language_code')]),
        ),
        migrations.AlterUniqueTogether(
            name='newsextendedtranslation',
            unique_together=set([('language_code', 'master'), ('newsbox_slug', 'language_code')]),
        ),
        migrations.AlterUniqueTogether(
            name='newscompletetranslation',
            unique_together=set([('language_code', 'master'), ('newsbox_slug', 'language_code')]),
        ),
    ]
